# Password generator
This module offers random password generation.

## Quick start

First of all, initialize:

```python
from rand_pass_generator import generate

password = generate()
```

## Contributing

Questions, comments, bug reports, and pull requests are all welcome.

## License

This software is licensed under the [MIT license](./LICENSE).